function [formants, amps, zeros] = armaspectrum(signal, arorder, maorder, Fs, alg)

% Author: Sean A. Fulop
% Revision Sept. 2010

% signal is a vectorized signal; arorder is number of poles, maorder is
% number of zeros in the transfer function of the model
% Fs is the signal sampling rate
% alg should be either 'rts' (calls HOSA tools) or 'armasa' (ARMASA tools)

window = tftb_window(length(signal),'Kaiser');

signal = window .* signal;

order_diff = arorder - maorder;

alg = upper(alg);
if strcmp(alg,'RTS'),
[avec, bvec] = armarts(signal, arorder, maorder);
elseif strcmp(alg,'ARMASA'),
    [avec, bvec] = sig2arma(signal, arorder, order_diff);
end;

fftn = 2048; % fft frame size

  % extract the positive frequency components
  if rem(fftn,2)==1
    ret_n = (fftn-1)/2;
  else
    ret_n = fftn/2;
  end

arspec = fft(avec, fftn);

maspec = fft(bvec, fftn);

% gain calculation after Markel and Gray eq. 2.44
autocor = xcorr(signal);
autocor = autocor((length(signal)):(2*length(signal)-1));
errvar = sum(autocor(1:(arorder+1)) .* avec(:));

ARMAPS = 10 .* log10(errvar*(maspec .* conj(maspec))./((Fs/fftn)*(arspec .* conj(arspec))));

PS = 10 .* log10(fft(signal,fftn) .* conj(fft(signal,fftn)));

high = Fs*(ret_n - 1)/fftn;

lowindex = 1;
highindex = round(high/Fs*fftn);
% set for full-range power spectrum

f = Fs*[lowindex:highindex]/fftn;

%figure('Position',[400,300,600,400]);
plot(f, ARMAPS(lowindex+1:highindex+1), 'r')
xlabel('Frequency (Hz)','FontName','times','FontSize',16)
ylabel('Magnitude (dB)','FontName','times','FontSize',16)
set(gca,'FontName','Courier','FontSize',12)

%npeaks = floor((arorder)/2);
%[peaks, amps] = pickpeak(ARMAPS(lowindex+1:highindex+1), npeaks, 5);
%peaks = peaks .* Fs/fftn

[zeros, poles, k] = tf2zpk(bvec, avec);

for a = 1:length(poles)
    deletions = [];
    if isreal(poles(a))
       deletions = [deletions a];
    end
end

if ~isequal(deletions, [])
    for a = 1:length(deletions)
        poles(deletions(a)) = [];
    end
end

vtrs = (Fs / (2*pi)) .* atan2(imag(poles), real(poles));

bandwidths = -(Fs / (2*pi)) .* log(real(poles).^2 + imag(poles).^2);

zeros = (Fs / (2*pi)) .* atan2(imag(zeros), real(zeros))

formants = [vtrs bandwidths]

amps = abs(poles);

inst = input('Overlay the regular fft spectrum (y/n)?','s');
if strcmp(inst,'n') || strcmp(inst,'no')
    return
else
    hold on
%    set(gcf,'CurrentAxes',inner);
%    set(inner,'NextPlot','add');
    plot(f, PS(lowindex+1:highindex+1), 'g')
    hold off
% plots the power spectrum on the same graph as the 
% ARMA power spectrum
end
