% Author: Sean A. Fulop
% Revision Sept. 2010

function [output, amps] = lpcroots(signal, order, Fs, taper, alg)

% signal is a vectorized signal; order is the number of LP coefficients in
% the model; Fs is the signal sampling rate
% taper should be entered as 'yes' or 'no'
% alg should be entered as one of 'autocor', 'cov', 'burg', or 'rcest'

taper = upper(taper);
if strcmp(taper,'NO'),
    window1 = tftb_window(length(signal),'Rect');
elseif strcmp(taper,'YES'),
window1 = tftb_window(length(signal),'Kaiser');
end;

signal = window1 .* signal;

alg = upper(alg);
if strcmp(alg,'AUTOCOR'),
[coeffs, E] = aryule(signal, order);
elseif strcmp(alg,'COV'),
    [coeffs, E] = arcov(signal, order);
elseif strcmp(alg,'BURG'),
    [coeffs, E] = arburg(signal, order);
elseif strcmp(alg, 'RCEST'),
    %coeffs = arrcest(signal, order);
    coeffs = arrcest(signal,order,0,3,order,length(signal),0,'biased');
end;

% gain calculation after Markel and Gray eq. 2.44
autocor = xcorr(signal);
autocor = autocor((length(signal)):(2*length(signal)-1));
errvar = sum(autocor(1:(order+1)) .* coeffs(:));
% errvar should be the variance or "power" of the error
% square root of this is the gain factor for the spectrum
% the supposed same quantity returned from Matlab's lpc routine is wrong
%gain = sqrt(errvar);

[z, poles, k] = tf2zpk(errvar, coeffs);

for a = 1:length(poles)
    deletions = [];
    if isreal(poles(a))
       deletions = [deletions a];
    end
end

if ~isequal(deletions, [])
    for a = 1:length(deletions)
        poles(deletions(a)) = [];
    end
end

vtrs = (Fs / (2*pi)) .* atan2(imag(poles), real(poles));

bandwidths = -(Fs / (2*pi)) .* log(real(poles).^2 + imag(poles).^2);

output = [vtrs bandwidths]
amps = abs(poles);
