
function [peaks, amps] = lpcspectrum(signal, order, Fs, taper, alg, linestyle)

% Author: Sean A. Fulop
% February 2010
% Requires free HOSA toolbox for peakpick function
% autocor, covariance, and Burg options require signal processing toolbox;
% rcest option requires only free HOSA toolbox

% signal is a vectorized signal; order is the number of LP coefficients in
% the model; Fs is the signal sampling rate
% taper should be entered as 'yes' or 'no'
% alg should be entered as one of 'autocor', 'cov', 'burg', or 'rcest'
% linestyle is useful for overlaying plots; it should be one of the Matlab
% LineStyle property specifiers, such as '-' for a plain line or ':' for a
% dotted line

% the desired number of peaks to be sought is set below in the code, as the
% value of npeaks

taper = upper(taper);
if strcmp(taper,'NO'),
    window1 = tftb_window(length(signal),'Rect');
elseif strcmp(taper,'YES'),
window1 = tftb_window(length(signal),'Kaiser');
%window1 = tftb_window(length(signal),'Hamming');
end;

signal = window1 .* signal;

alg = upper(alg);
if strcmp(alg,'AUTOCOR'),
[coeffs, E] = aryule(signal, order);
elseif strcmp(alg,'COV'),
    [coeffs, E] = arcov(signal, order);
elseif strcmp(alg,'BURG'),
    [coeffs, E] = arburg(signal, order);
elseif strcmp(alg, 'RCEST'),
    %coeffs = arrcest(signal, order);
    coeffs = arrcest(signal,order,0,3,order,length(signal),0,'biased');
end;

% E is the variance (power) of the prediction error, so its square root
% should equal the gain, but it is wrong apparently

fftn = 2048; % fft frame size

  % extract the positive frequency components
  if rem(fftn,2)==1
    ret_n = (fftn-1)/2;
  else
    ret_n = fftn/2;
  end

specinv = fft(coeffs, fftn);

% gain calculation after Markel and Gray eq. 2.44
autocor = xcorr(signal);
autocor = autocor((length(signal)):(2*length(signal)-1));
errvar = sum(autocor(1:(order+1)) .* coeffs(:));
% errvar should be the variance or "power" of the error
% square root of this is the gain factor for the spectrum
% the supposed same quantity returned from Matlab's lpc routine is wrong
gain = sqrt(errvar);
%gain = sqrt(E);
spec = gain ./ specinv;

LPPS = 10 .* log10(spec .* conj(spec));

PS = 10 .* log10(fft(signal,fftn) .* conj(fft(signal,fftn)));

high = Fs*(ret_n - 1)/fftn;

lowindex = 1;
highindex = round(high/Fs*fftn);
% set for full-range power spectrum

f = Fs*[lowindex:highindex]/fftn;

%if ~ishold
%figure('Position',[400,300,600,400]);
%end
plot(f, LPPS(lowindex+1:highindex+1), 'k','LineStyle',linestyle)
xlabel('Frequency (Hz)','FontName','times','FontSize',16)
ylabel('Magnitude (dB)','FontName','times','FontSize',16)
set(gca,'FontName','Courier','FontSize',12)

%npeaks = floor((order-2)/2);
npeaks = 6;
[peaks, amps] = pickpeak(LPPS(lowindex+1:highindex+1), npeaks, 5);
peaks = peaks .* Fs/fftn

inst = input('Overlay the regular fft spectrum (y/n/h)?','s');
if strcmp(inst,'n') | strcmp(inst,'no')
    return
elseif strcmp(inst,'h')
    hold on
    return
else
    hold on
%    set(gcf,'CurrentAxes',inner);
%    set(inner,'NextPlot','add');
    plot(f, PS(lowindex+1:highindex+1), 'g')
    hold off
% plots the power spectrum on the same graph as the 
% standard linear prediction power spectrum
end