
% Sean A. Fulop
% June 29, 2010
% plot ensemble average power spectrum of multiple signals of equal length

function [PS, f] = powerspec_ensemble(signals, Fs, low, high)

% signals is a matrix of column vector signals

fftn = max(length(signals),2048);

window = tftb_window(length(signals),'Kaiser');

% extract the positive frequency components
if rem(fftn,2)==1
  ret_n = (fftn-1)/2;
else
  ret_n = fftn/2;
end

if high > Fs*(ret_n-1)/fftn
    high = Fs*(ret_n-1)/fftn;
end

periodogram_matrix = [];
for index = signals
periodogram_one = fft((index.*window),fftn) .* conj(fft((index.*window),fftn));
periodogram_matrix = [periodogram_matrix periodogram_one];
end

periodogram_ensemble = mean(periodogram_matrix, 2);
PS = 10 .* log10(periodogram_ensemble);

lowindex = round(low/Fs*fftn);
if lowindex == 0
    lowindex = 1;
end
highindex = round(high/Fs*fftn);
f = Fs*[lowindex:highindex]/fftn;

plot(f, PS(lowindex+1:highindex+1), 'g')
xlabel('Frequency (Hz)','FontName','times','FontSize',16)
ylabel('Magnitude (dB)','FontName','times','FontSize',16)
set(gca,'FontName','Courier','FontSize',14)



