% by Sean Fulop, version August 2010
% relies on some code originally written by Paul Kienzel for Octave
% and also a trick or two by Kelly Fitz

function [STFTpos, f, tforspgm] = specgram_2010(signal, Fs, window, overlap, fftn, low, high, clip)

% Arguments: signal is the signal, with sampling rate Fs;
  % window is the analysis frame length, in sample points;
  % overlap is the number of points the frames overlap, equaling window minus frame
  % advance;
  % fftn is the discrete Fourier transform analysis length, in samples;
  % low and high are the frequency limits of the display, in Hz;
  % clip is a negative number which specifies the number of dB down from
  % the maximum that are to be shown---everything quieter is clipped
  
len = length(signal);

window = tftb_window(window,'Kaiser');
  
% compute window offsets
win_size = length(window);
step = win_size - overlap;

% build matrix of windowed data slices
% each column is a data window
% Follow Paul Kienzle's old Octave program here 
% with some tricks from Kelly Fitz

offset = [ 0 : step : len-win_size-1 ];
WW = window*ones(1,length(offset));

idx = ((1:win_size)'*ones(1,length(offset))) + (ones(win_size,1)*offset);
S = signal(idx+1).*WW;

STFT = fft(S,fftn);

% extract the positive frequency components
if rem(fftn,2)==1
  ret_n = (fftn-1)/2;
else
  ret_n = fftn/2;
end

if high > Fs*(ret_n-1)/fftn
    high = Fs*(ret_n-1)/fftn;
end

lowindex = round(low/Fs*fftn);
if lowindex == 0
    lowindex = 1;
end
highindex = round(high/Fs*fftn);

f = Fs*[lowindex-1:highindex-1] ./ fftn;

tforspgm = (offset + win_size/2) ./ Fs;

% Truncate STFT matrices to the frequency range to be plotted

STFTpos = STFT(lowindex:highindex, :);
STFTmag = abs(STFTpos); % magnitude of STFT
STFTmag = STFTmag ./ max(max(STFTmag)); % normalize so max magnitude will be 0 db
STFTmag = 20*log10(STFTmag); % convert to log magnitude, decibel scale

for slice = 1:length(offset)
    %for x = lowindex:highindex
    STFTmag(:,slice) = max(STFTmag(:,slice),clip); %clip spgm plot
        %end
end



figure('Position',[400,300,900,400]);
pcolor(1000*tforspgm, f, STFTmag );
axis xy;
colormap(flipud(gray));
shading interp;
xlabel('Time (ms)','FontName','times','FontSize',16)
ylabel('Frequency (Hz)','FontName','times','FontSize',16)
set(gca,'FontName','Courier','FontSize',14)

end